==> attal_0.8.orig.tar.gz: attal-0.8/i18n/ru/attal_client_ru.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ClientInterface</name>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation>CTRL+D</translation>
    </message>
    <message>
        <source>CTRL+M</source>
        <translation>CTRL+M</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Невозможно установить соединение</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Вы уже соеденены с сервером.  Пожалуйста, разорвите ваше соединение сначала.</translation>
    </message>
    <message>
        <source>Attal - Lords of Doom</source>
        <translation>Attal - Lords of Doom</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Установить соединение с сервером</translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation>&amp;Установить соединение с сервером</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Разорвать соединение</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Разорвать соединение</translation>
    </message>
    <message>
        <source>Mini map</source>
        <translation>Мини-карта</translation>
    </message>
    <message>
        <source>&amp;Mini map</source>
        <translation>&amp;Мини-карта</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <source>Match</source>
        <translation>Матч</translation>
    </message>
    <message>
        <source>Do you want abandon the match ?</source>
        <translation>Вы хотите прервать матч?</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Полоска состояния</translation>
    </message>
    <message>
        <source>Tab window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Tab Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation>Соединение с сервером</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Хост:</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Имя:</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Установить соединение</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
</TS>

==> attal_0.9.1.orig.tar.gz: attal-0.9.1/i18n/ru/attal_client_ru.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ClientInterface</name>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation>CTRL+D</translation>
    </message>
    <message>
        <source>CTRL+M</source>
        <translation>CTRL+M</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Невозможно установить соединение</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Вы уже соеденены с сервером.  Пожалуйста, разорвите ваше соединение сначала.</translation>
    </message>
    <message>
        <source>Attal - Lords of Doom</source>
        <translation>Attal - Lords of Doom</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Установить соединение с сервером</translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation>&amp;Установить соединение с сервером</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Разорвать соединение</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Разорвать соединение</translation>
    </message>
    <message>
        <source>Mini map</source>
        <translation>Мини-карта</translation>
    </message>
    <message>
        <source>&amp;Mini map</source>
        <translation>&amp;Мини-карта</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <source>Match</source>
        <translation>Матч</translation>
    </message>
    <message>
        <source>Do you want abandon the match ?</source>
        <translation>Вы хотите прервать матч?</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Полоска состояния</translation>
    </message>
    <message>
        <source>Tab window</source>
        <translation>Окно табуляции</translation>
    </message>
    <message>
        <source>&amp;Tab Window</source>
        <translation>&amp;Окно табуляции</translation>
    </message>
    <message>
        <source>CTRL+T</source>
        <translation>CTRL+T</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Полный экран</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Полный экран</translation>
    </message>
    <message>
        <source>CTRL+F</source>
        <translation>CTRL+F</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Невозможно загрузить тему</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Тема</translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation>не была успешно загружена</translation>
    </message>
    <message>
        <source>Fast Server </source>
        <translation>&quot;Быстрый&quot; сервер</translation>
    </message>
    <message>
        <source>Fast &amp;Server</source>
        <translation>&quot;Быстрый&quot; &amp;Сервер</translation>
    </message>
    <message>
        <source>CTRL+S</source>
        <translation>CTRL+S</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation>Соединение с сервером</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Хост:</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Имя:</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Установить соединение</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
</TS>
